@@ -32,7 +32,7 @@ Version 0.01
 
 =cut
 
-our $VERSION = '2.43';
+our $VERSION = '2.44';
 
 =head1 SYNOPSIS
 
@@ -387,7 +387,6 @@ has 'custom_command' => (
     isa => 'Str',
     predicate => 'has_custom_command',
     clearer => 'clear_custom_command',
-    default => q{},
 );
 
 =head1 Internal Variables
@@ -484,27 +483,6 @@ has 'node' => (
     }
 );
 
-=head2 cmd
-
-Current command specified by infile
-
-=cut
-
-#has 'cmd' => (
-    #traits  => ['String', 'NoGetopt'],
-    #is => 'rw',
-    #isa => 'Str',
-    #required => 0,
-    ##default => q{},
-    #handles => {
-        #add_cmd => 'append',
-        #match_cmd => 'match',
-    #},
-    #builder => '_build_cmd',
-    #clearer => 'clear_cmd',
-    #predicate => 'has_cmd',
-#);
-
 =head2 batch
 
 List of commands to submit to slurm
